==> haskell-cipher-aes-0.2.11-96-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cipher-aes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cipher-aes
version: 0.2.11
id: cipher-aes-0.2.11-9AQVkLnXjCkKEt3BMixXJL
key: cipher-aes-0.2.11-9AQVkLnXjCkKEt3BMixXJL
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
homepage: https://github.com/vincenthz/hs-cipher-aes
synopsis: Fast AES cipher implementation with advanced mode of operations
description:
    Fast AES cipher implementation with advanced mode of operations.
    .
    The modes of operations available are ECB (Electronic code book),
    CBC (Cipher block chaining), CTR (Counter), XTS (XEX with ciphertext stealing),
    GCM (Galois Counter Mode).
    .
    The AES implementation uses AES-NI when available (on x86 and x86-64 architecture),
    but fallback gracefully to a software C implementation.
    .
    The software implementation uses S-Boxes, which might suffer for cache timing issues.
    However do notes that most other known software implementations, including very popular
    one (openssl, gnutls) also uses similar implementation. If it matters for your
    case, you should make sure you have AES-NI available, or you'\''ll need to use a different
    implementation.
    .
category: Cryptography
abi: 443d0115b16098b2e144d2a8c41db300
exposed: True
exposed-modules:
    Crypto.Cipher.AES
import-dirs: /usr/lib/ghc-8.6.5/site-local/cipher-aes-0.2.11
library-dirs: /usr/lib/ghc-8.6.5/site-local/cipher-aes-0.2.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/cipher-aes-0.2.11
hs-libraries: HScipher-aes-0.2.11-9AQVkLnXjCkKEt3BMixXJL
depends:
    base-4.12.0.0 byteable-0.1.1-9guyEXUUK503mzSnI32g2S
    bytestring-0.10.8.2
    crypto-cipher-types-0.0.9-17KnAsArwMDKS50OczHA7y
    securemem-0.1.10-AgRbjRbsMHcJeKnVmNGCBY
haddock-interfaces: /usr/share/doc/haskell-cipher-aes/html/cipher-aes.haddock
haddock-html: /usr/share/doc/haskell-cipher-aes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cipher-aes-0.2.11-100-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cipher-aes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cipher-aes
version: 0.2.11
id: cipher-aes-0.2.11-J1w0NflMQpb9ZA5X4LAUZv
key: cipher-aes-0.2.11-J1w0NflMQpb9ZA5X4LAUZv
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
homepage: https://github.com/vincenthz/hs-cipher-aes
synopsis: Fast AES cipher implementation with advanced mode of operations
description:
    Fast AES cipher implementation with advanced mode of operations.
    .
    The modes of operations available are ECB (Electronic code book),
    CBC (Cipher block chaining), CTR (Counter), XTS (XEX with ciphertext stealing),
    GCM (Galois Counter Mode).
    .
    The AES implementation uses AES-NI when available (on x86 and x86-64 architecture),
    but fallback gracefully to a software C implementation.
    .
    The software implementation uses S-Boxes, which might suffer for cache timing issues.
    However do notes that most other known software implementations, including very popular
    one (openssl, gnutls) also uses similar implementation. If it matters for your
    case, you should make sure you have AES-NI available, or you'\''ll need to use a different
    implementation.
    .
category: Cryptography
abi: f0b83584fca745113611cb45f3e7677c
exposed: True
exposed-modules:
    Crypto.Cipher.AES
import-dirs: /usr/lib/ghc-8.6.5/site-local/cipher-aes-0.2.11
library-dirs: /usr/lib/ghc-8.6.5/site-local/cipher-aes-0.2.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/cipher-aes-0.2.11
hs-libraries: HScipher-aes-0.2.11-J1w0NflMQpb9ZA5X4LAUZv
depends:
    base-4.12.0.0 byteable-0.1.1-9guyEXUUK503mzSnI32g2S
    bytestring-0.10.8.2 crypto-cipher-types-0.0.9-DXpvZNJsGutNPf1lCSHHK
    securemem-0.1.10-L4TfLmHXcEx8teV0rzp6zE
haddock-interfaces: /usr/share/doc/haskell-cipher-aes/html/cipher-aes.haddock
haddock-html: /usr/share/doc/haskell-cipher-aes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
